pub fn new_tx_verification_data( tx: Transaction, ) -> Result<TransactionVerificationData, ConsensusError>
Creates a new [TransactionVerificationData] from a [Transaction].
TransactionVerificationData
Transaction
This function will return Err if the transaction is malformed, although returning Ok does not necessarily mean the tx is correctly formed.
Err
Ok