pub struct VerificationWanted { /* private fields */ }Expand description
The step where the type of verification is decided.
Implementations
Sourceimpl VerificationWanted
impl VerificationWanted
Sourcepub fn only_semantic(self, hf: HardFork) -> SemanticVerification
pub fn only_semantic(self, hf: HardFork) -> SemanticVerification
Only semantic verification.
Semantic verification is verification that can done without other blockchain data. The HardFork
is technically other blockchain data but excluding it reduces the amount of things that can be checked
significantly, and it is easy to get compared to other blockchain data needed for contextual validation.
Sourcepub fn full<D: Database>(
self,
current_chain_height: usize,
top_hash: [u8; 32],
time_for_time_lock: u64,
hf: HardFork,
database: D,
batch_prep_cache: Option<&BatchPrepareCache>,
) -> FullVerification<'_, D>
pub fn full<D: Database>( self, current_chain_height: usize, top_hash: [u8; 32], time_for_time_lock: u64, hf: HardFork, database: D, batch_prep_cache: Option<&BatchPrepareCache>, ) -> FullVerification<'_, D>
Full verification.
Fully verify the transactions, all checks will be performed, if they were already performed then they won’t be done again unless necessary.