pub struct PrepTransactions { /* private fields */ }Expand description
The preparation phase of transaction verification.
The order of transactions will be kept throughout the verification process, transactions
inserted with PrepTransactions::append_prepped_txs will be put before transactions given
in PrepTransactions::append_txs
Implementations
Sourceimpl PrepTransactions
impl PrepTransactions
Sourcepub fn append_txs(self, txs: Vec<Transaction>) -> Self
pub fn append_txs(self, txs: Vec<Transaction>) -> Self
Append some new transactions to prepare.
Sourcepub fn append_prepped_txs(self, txs: Vec<TransactionVerificationData>) -> Self
pub fn append_prepped_txs(self, txs: Vec<TransactionVerificationData>) -> Self
Append some already prepped transactions.
Sourcepub fn prepare(self) -> Result<VerificationWanted, ConsensusError>
pub fn prepare(self) -> Result<VerificationWanted, ConsensusError>
Prepare the transactions and advance to the next step: VerificationWanted.
[rayon]
This function will use [rayon] to parallelize the preparation process, so should not be called
in an async function, unless all the transactions given were already prepared, i.e. Self::append_prepped_txs.